@@ -16,12 +16,13 @@ def send_email(subject, message, sender, recipients):
     )
 
 
-def send_templated_email(template, subject, recipients, context={}):
+def send_templated_email(template, subject, recipients, sender, context={}):
     """
     Sends and email using the given template to the given recipients.
     """
     return send_email(
         subject,
         resolve_template(template).render(Context(context)),
+        sender,
         recipients,
     )
