@@ -10,7 +10,7 @@ log = logging.getLogger('coreutils.middleware')
 
 class SiteUrlMiddleware(object):
     def process_request(self, request):
-        request.site_url = site_url()
+        request.site_url = site_url(request)
 
 
 class SubdomainMiddleware(object):
